@@ -13,7 +13,7 @@ class Database:
     def load_session(self):
         # TODO: should we checkout scoped sessions
         Session = sessionmaker(bind=self.engine)
-        return scoped_session(Session())
+        return scoped_session(Session)
 class RDSDatabase(Database):
     def __init__(self, user, password, host, port, database, **kwargs):
         super().__init__(user, password, host, port, database, **kwargs)
